//+------------------------------------------------------------------+
//|                                                   PriceVSwma.mq4 |
//|                      Copyright  2004, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+
#property copyright "Copyright  2004, MetaQuotes Software Corp."
#property link      "perky_z@yahoo.com"

#property indicator_separate_window
#property indicator_buffers 2
#property indicator_color1  White
#property indicator_color2  Red
#property indicator_width1  2
#property indicator_width2  2

extern int    smoothing        = 13;
extern bool   alertsOn         = true;
extern bool   alertsOnCurrent  = true;
extern bool   alertsMessage    = true;
extern bool   alertsSound      = false;
extern bool   alertsNotify     = true;
extern bool   alertsEmail      = true;
extern string soundFile        = "alert2.wav"; 

extern bool   ShowArrows       = false;
extern string arrowsIdentifier = "zlstoch Arrows1";
extern double arrowsUpperGap   = 1.0;
extern double arrowsLowerGap   = 1.0;
extern color  arrowsUpColor    = LimeGreen;
extern color  arrowsDnColor    = Red;
extern int    arrowsUpCode     = 241;
extern int    arrowsDnCode     = 242;


//
//
//
//
//

double TrendBuffer[];
double LoBuffer[];
double trend[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
   IndicatorBuffers(3);
   SetIndexBuffer(0,TrendBuffer);
   SetIndexBuffer(1,LoBuffer);
   SetIndexBuffer(2,trend);
   IndicatorShortName("ZLS("+smoothing+")");
   
return(0);
}
int deinit() 
{  
   deleteArrows(); 
   
return(0); 
}

//
//
//
//
//

int start() 
{
   int counted_bars=IndicatorCounted();
   int i,limit;

   if(counted_bars<0) return(-1);
   if(counted_bars>0) counted_bars--;
         limit = MathMin(Bars-counted_bars,Bars-1);

   //
   //
   //
   //
   //

   for(i=limit; i>=0; i--)
   {
      double stok5 = (iStochastic(NULL,0,52,12,3,MODE_LWMA,NULL,MODE_MAIN,i))*0.00;
      double stok4 = (iStochastic(NULL,0,34, 8,3,MODE_LWMA,NULL,MODE_MAIN,i))*0.0;
      double stok3 = (iStochastic(NULL,0,21, 5,3,MODE_LWMA,NULL,MODE_MAIN,i))*0.10;
      double stok2 = (iStochastic(NULL,0,12, 4,3,MODE_LWMA,NULL,MODE_MAIN,i))*0.65;
      double stok1 = (iStochastic(NULL,0, 8, 3,3,MODE_LWMA,NULL,MODE_MAIN,i))*0.25;
      TrendBuffer[i] = stok1+stok2+stok3+stok4+stok5;
      LoBuffer[i]    = TrendBuffer[i] /smoothing + LoBuffer[i+1]*(smoothing-1)/smoothing;
      trend[i] = trend[i+1];    
      if (TrendBuffer[i] > LoBuffer[i]) trend[i] = 1;
      if (TrendBuffer[i] < LoBuffer[i]) trend[i] =-1;
      
	    //
       //
       //
       //
       //
       
       if (ShowArrows)
       {
          deleteArrow(Time[i]);
          if (trend[i] != trend[i+1])
          {
            if (trend[i] == 1)  drawArrow(i,arrowsUpColor,arrowsUpCode,false);
            if (trend[i] ==-1)  drawArrow(i,arrowsDnColor,arrowsDnCode, true);
          }
       }
               
   }
   
   //
   //
   //
   //
   //
   
   if (alertsOn)
   {
      if (alertsOnCurrent)
            int whichBar = 0;
      else      whichBar = 1;
      if (trend[whichBar] != trend[whichBar+1])
      if (trend[whichBar] == 1)
            doAlert("up");
      else  doAlert("down");       
   }   
return(0);
}

//
//
//
//
//

void drawArrow(int i,color theColor,int theCode,bool up)
{
   string name = arrowsIdentifier+":"+Time[i];
   double gap  = iATR(NULL,0,20,i);   
   
      //
      //
      //
      //
      //
      
      ObjectCreate(name,OBJ_ARROW,0,Time[i],0);
         ObjectSet(name,OBJPROP_ARROWCODE,theCode);
         ObjectSet(name,OBJPROP_COLOR,theColor);
         if (up)
               ObjectSet(name,OBJPROP_PRICE1,High[i] + arrowsUpperGap * gap);
         else  ObjectSet(name,OBJPROP_PRICE1,Low[i]  - arrowsLowerGap * gap);
}

//
//
//
//
//

void deleteArrows()
{
   string lookFor       = arrowsIdentifier+":";
   int    lookForLength = StringLen(lookFor);
   for (int i=ObjectsTotal()-1; i>=0; i--)
   {
      string objectName = ObjectName(i);
         if (StringSubstr(objectName,0,lookForLength) == lookFor) ObjectDelete(objectName);
   }
}

//
//
//
//
//

void deleteArrow(datetime time)
{
   string lookFor = arrowsIdentifier+":"+time; ObjectDelete(lookFor);
}

//------------------------------------------------------------------
//                                                                  
//------------------------------------------------------------------
//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message =  Symbol()+" at "+TimeToStr(TimeLocal(),TIME_SECONDS)+" Zerolagstochs changed trend to "+doWhat;
             if (alertsMessage) Alert(message);
             if (alertsNotify)  SendNotification(StringConcatenate(Symbol(), Period() ," Zerolagstochs " +" "+message));
             if (alertsEmail)   SendMail(StringConcatenate(Symbol()," Zerolagstochs "),message);
             if (alertsSound)   PlaySound(soundFile);
      }
}


